@@ -2,4 +2,4 @@ from enum import StrEnum, auto
 
 
 class CQScope(StrEnum):
-    ON_COMMAND = auto()
+    TRANSACTION = auto()
